import os
from magicapi.Errors.MagicExceptions import (
    MagicException,
    BackendException,
    FrontendException,
    FirestoreException,
    TwilioException,
)
